
from pynation.cli import cli1 as cli

if __name__ == '__main__':
    cli()
